diff -Nru cxref-1.6e/debian/changelog cxref-1.6e/debian/changelog
--- cxref-1.6e/debian/changelog	2021-01-03 17:31:29.000000000 +0100
+++ cxref-1.6e/debian/changelog	2022-07-04 18:08:52.000000000 +0200
@@ -1,3 +1,10 @@
+cxref (1.6e-3.2) unstable; urgency=medium
+
+  * Non-maintainer upload by the Reproducible Builds team.
+  * Fix reproducibility issues (Closes: #995886, #995896, #995953, #995954)
+
+ -- Philip Rinn <rinni@inventati.org>  Mon, 04 Jul 2022 18:08:52 +0200
+
 cxref (1.6e-3.1) unstable; urgency=medium
 
   * Non maintainer upload by the Reproducible Builds team.
diff -Nru cxref-1.6e/debian/patches/0002-cpp-cxref-cpp-configure.in-Use-specific-path-for-EGR.patch cxref-1.6e/debian/patches/0002-cpp-cxref-cpp-configure.in-Use-specific-path-for-EGR.patch
--- cxref-1.6e/debian/patches/0002-cpp-cxref-cpp-configure.in-Use-specific-path-for-EGR.patch	1970-01-01 01:00:00.000000000 +0100
+++ cxref-1.6e/debian/patches/0002-cpp-cxref-cpp-configure.in-Use-specific-path-for-EGR.patch	2022-07-04 18:08:52.000000000 +0200
@@ -0,0 +1,34 @@
+From 0f5bc18bb094b9c199b2471830e2a25ee255c04c Mon Sep 17 00:00:00 2001
+From: Vagrant Cascadian <vagrant@reproducible-builds.org>
+Date: Tue, 5 Oct 2021 05:54:24 +0000
+Subject: [PATCH 2/2] cpp/cxref-cpp-configure.in: Use specific path for EGREP.
+
+This hard-codes the path to grep to ensure reproducible builds
+regardless of weather the package was built on a usrmerge or
+non-usrmerge system.
+
+Passing EGREP via configure did not appear to work, possibly due to
+makefile variable inheritance issues, though that would be preferable
+if it could be made to work.
+
+https://tests.reproducible-builds.org/debian/issues/unstable/paths_vary_due_to_usrmerge_issue.html
+---
+ cpp/cxref-cpp-configure.in | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/cpp/cxref-cpp-configure.in b/cpp/cxref-cpp-configure.in
+index d37764f..ab50792 100755
+--- a/cpp/cxref-cpp-configure.in
++++ b/cpp/cxref-cpp-configure.in
+@@ -18,7 +18,7 @@
+ # Programs and paths
+ # (Default to the ones from the configure script).
+ 
+-EGREP="@EGREP@"
++EGREP="/bin/egrep -E"
+ 
+ prefix="@prefix@"
+ datarootdir="@datarootdir@"
+-- 
+2.30.2
+
diff -Nru cxref-1.6e/debian/patches/series cxref-1.6e/debian/patches/series
--- cxref-1.6e/debian/patches/series	2018-01-30 17:50:37.000000000 +0100
+++ cxref-1.6e/debian/patches/series	2022-07-04 18:08:52.000000000 +0200
@@ -3,3 +3,4 @@
 kr-crash-doc
 c_warning_cleanups_and_defines_for_Float128
 # CPPFLAGS-hardening-patch
+0002-cpp-cxref-cpp-configure.in-Use-specific-path-for-EGR.patch
diff -Nru cxref-1.6e/debian/rules cxref-1.6e/debian/rules
--- cxref-1.6e/debian/rules	2018-01-30 17:50:37.000000000 +0100
+++ cxref-1.6e/debian/rules	2022-07-04 18:08:52.000000000 +0200
@@ -16,6 +16,12 @@
 
 DPKG_EXPORT_BUILDFLAGS=1
 
+# Ensure texlive respects SOURCE_DATE_EPOCH
+export FORCE_SOURCE_DATE=1
+
+# Force locale to avoid differences when building with obscure locales
+export LC_ALL=C.UTF-8
+
 include /usr/share/dpkg/buildflags.mk
 
 build: build-arch build-indep
@@ -61,6 +67,9 @@
 	$(MAKE) install DESTDIR=`pwd`/debian/tmp
 	$(MAKE) docs DESTDIR=`pwd`/debian/tmp
 
+	# Remove build path from documentation
+	find doc/ -type f -exec sed -i -e "s,$(CURDIR),BUILDPATH,g" '{}' \;
+
 	mkdir -p debian/tmp/usr/share/cxref
 	mv debian/tmp/etc/cxref/cxref-cpp.defines debian/tmp/usr/share/cxref
 
